==> ask-jennie-0.0.3.tar.gz: ask-jennie-0.0.3/jennie/setup/__init__.py <==
from jennie.constants import *
from getpass import getpass
from jennie.utils.apicallhandler import APICalls
from jennie.utils.helper import take_user_input, get_user_access_token, TOKEN_PATH

__version__ = "0.0.3"
__latest__ = "0.0.3"
__description__ = 'The package targets protocol for uploading and reusing task and libraries'
__author__ = 'ASK Jennie Developer <dextrop@ask-jennie.com>'

version_info = '''
__version__ = {0}
__latest__ = {1}
__description__ = {2}
__author__ = {3}
__supported_platforms__ = 'Angular, Django, Ubuntu Servers'
'''.format(__version__, __latest__, __description__, __author__)


class Setup():
    def __init__(self, logger):
        self.state = 0
        self.logger = logger
        self.api_call = APICalls(self.logger)

    def show_version(self):
        print (version_info)

        user_info = self.get_logged_in_user()
        if (user_info == None):
            print ("Not logged in, To use the software try login using jennie setup")
            return

        print("User Name :", user_info["fullname"])
        print("User Email :", user_info["email"])

    def get_logged_in_user(self):
        user_saved_info = None
        userinfo = get_user_access_token()
        return userinfo

    def login_to_ask_jennie(self, email, password):
        response = self.api_call.login_api_call(email=email, password=password)
        with open(TOKEN_PATH, 'w') as f:
            json.dump(response, f)

        print ("User Logged In Successfully")
        return True

    def setup(self, email=None):
        if email == None:
            info = take_user_input(USER_INPUT_FOR_SETUP)
            email = info["email"]

        self.email = email
        token_info = self.get_logged_in_user()
        if (token_info):
            raise ValueError("User already logged in, try logout to re setup < jennie logout > ")
        else:
            print ("Continue Login, Enter Information")
            print ("Input Password for ASK Jennie Email:  ", self.email)
            password = getpass()
            return self.login_to_ask_jennie (self.email, password)

    def logout(self):
        if (self.get_logged_in_user() != None):
            command = "rm -rf {}".format(TOKEN_PATH)
            os.system(command)
            print ("Logged out successfully")
        else:
            print ("User not logged in")
        return True

==> ask-jennie-0.0.10.tar.gz: ask-jennie-0.0.10/jennie/setup/__init__.py <==
from jennie.constants import *
from getpass import getpass
from jennie.utils.apicallhandler import APICalls
from jennie.utils.helper import take_user_input, get_user_access_token, TOKEN_PATH

__version__ = "0.0.10"
__latest__ = "0.0.10"
__description__ = 'The package targets protocol for uploading and reusing task and libraries'
__author__ = 'ASK Jennie Developer <dextrop@ask-jennie.com>'

version_info = '''
__version__ = {0}
__latest__ = {1}
__description__ = {2}
__author__ = {3}
__supported_platforms__ = 'Angular, Django, Ubuntu Servers'
'''.format(__version__, __latest__, __description__, __author__)


class Setup():
    def __init__(self, logger):
        self.state = 0
        self.logger = logger
        self.api_call = APICalls(self.logger)

    def show_version(self):
        print (version_info)

        user_info = self.get_logged_in_user()
        if (user_info == None):
            print ("Not logged in, To use the software try login using jennie setup")
            return

        print("User Name :", user_info["fullname"])
        print("User Email :", user_info["email"])

    def get_logged_in_user(self):
        user_saved_info = None
        try:
            userinfo = get_user_access_token()
        except Exception as e:
            return None
        return userinfo

    def login_to_ask_jennie(self, email, key):
        response = self.api_call.login_via_google(email=email, key=key)
        with open(TOKEN_PATH, 'w') as f:
            json.dump(response, f)

        print ("User Logged In Successfully")
        return True

    def setup(self, email=None):
        if email == None:
            info = take_user_input(USER_INPUT_FOR_SETUP)
            email = info["email"]

        self.email = email
        token_info = self.get_logged_in_user()
        if (token_info):
            raise ValueError("User already logged in, try logout to re setup < jennie logout > ")
        else:
            print ("Continue Login, Enter Information")
            key = input ("Input Application KEY \n>> ")
            return self.login_to_ask_jennie (self.email, key)

    def logout(self):
        if (self.get_logged_in_user() != None):
            command = "rm -rf {}".format(TOKEN_PATH)
            os.system(command)
            print ("Logged out successfully")
        else:
            print ("User not logged in")
        return True
